@@ -13,7 +13,7 @@ ticommand = on_startswith(".ti", priority=2)
 licommand = on_startswith(".li", priority=2)
 coc = on_startswith(".coc", priority=2)
 sccommand = on_startswith(".sc", priority=2)
-rdcommand = on_startswith(".", priority=3)
+rdcommand = on_startswith(".r", priority=3)
 
 
 @rdhelp.handle()
@@ -34,7 +34,7 @@ async def enhandler(bot: Bot, event: Event):
 
 @rdcommand.handle()
 async def rdcommandhandler(bot: Bot, event: Event):
-    args = str(event.get_message())[1:].strip()
+    args = str(event.get_message())[2:].strip()
     uid = event.get_session_id()
     if args and not("." in args):
         rrd = rd(args)
